import * as _backstage_backend_plugin_api from '@backstage/backend-plugin-api';
import { EntityFilterQuery } from '@backstage/catalog-client';
import { Entity } from '@backstage/catalog-model';
import { TechDocsDocument } from '@backstage/plugin-techdocs-node';

/** @public */
type TechDocsCollatorEntityTransformer = (entity: Entity) => Partial<Omit<TechDocsDocument, 'location' | 'authorization'>>;

/** @public */
declare const defaultTechDocsCollatorEntityTransformer: TechDocsCollatorEntityTransformer;

/** @public */
interface MkSearchIndexDoc {
    title: string;
    text: string;
    location: string;
    tags?: string[];
}
/** @public */
type TechDocsCollatorDocumentTransformer = (doc: MkSearchIndexDoc) => Partial<Omit<TechDocsDocument, 'location' | 'authorization' | 'kind' | 'namespace' | 'name' | 'lifecycle' | 'owner'>>;

/** @public */
interface TechDocsCollatorEntityTransformerExtensionPoint {
    setTransformer(transformer: TechDocsCollatorEntityTransformer): void;
    setDocumentTransformer(transformer: TechDocsCollatorDocumentTransformer): void;
}
/**
 * Extension point used to customize the TechDocs collator entity transformer.
 *
 * @public
 */
declare const techdocsCollatorEntityTransformerExtensionPoint: _backstage_backend_plugin_api.ExtensionPoint<TechDocsCollatorEntityTransformerExtensionPoint>;
/** @public */
interface TechDocsCollatorEntityFilterExtensionPoint {
    setEntityFilterFunction(filterFunction: (entities: Entity[]) => Entity[]): void;
    setCustomCatalogApiFilters(apiFilters: EntityFilterQuery): void;
}
/**
 * Extension point used to filter the entities that the collator will use.
 *
 * @public
 */
declare const techDocsCollatorEntityFilterExtensionPoint: _backstage_backend_plugin_api.ExtensionPoint<TechDocsCollatorEntityFilterExtensionPoint>;
/**
 * @public
 * Search backend module for the TechDocs index.
 */
declare const _default: _backstage_backend_plugin_api.BackendFeature;

export { type MkSearchIndexDoc, type TechDocsCollatorDocumentTransformer, type TechDocsCollatorEntityFilterExtensionPoint, type TechDocsCollatorEntityTransformer, type TechDocsCollatorEntityTransformerExtensionPoint, _default as default, defaultTechDocsCollatorEntityTransformer, techDocsCollatorEntityFilterExtensionPoint, techdocsCollatorEntityTransformerExtensionPoint };
